==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QKeyEvent_shell.h <==
#ifndef QKEYEVENT_SHELL_H
#define QKEYEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtGui/qinputdevice.h>
#include <qtcore-config.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtJambi/RegistryAPI>


class QKeyEvent_shell : public QKeyEvent, public QtJambiShellInterface
{
public:
    QKeyEvent_shell(QEvent::Type type0, int key1, Qt::KeyboardModifiers modifiers2, const QString& text3 = QString(), bool autorep4 = false, quint16 count5 = 1);
    QKeyEvent_shell(QEvent::Type type0, int key1, Qt::KeyboardModifiers modifiers2, quint32 nativeScanCode3, quint32 nativeVirtualKey4, quint32 nativeModifiers5, const QString& text6 = QString(), bool autorep7 = false, quint16 count8 = 1, const QInputDevice* device9 = QInputDevice::primaryKeyboard());
    QKeyEvent_shell(const QKeyEvent& arg__1);
    ~QKeyEvent_shell() override;

    QKeyEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QKeyEvent_access : public QKeyEvent
{
    void __qt_assign_cref_QKeyEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setAutoRepeat_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean autoRepeat0);
    void setCount_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jshort count0);
    void setScanCode_quint32(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint scanCode0);
    jint scanCode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setVirtualKey_quint32(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint virtualKey0);
    jint virtualKey(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QKEYEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QKeyEvent_shell.h <==
#ifndef QKEYEVENT_SHELL_H
#define QKEYEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtGui/qinputdevice.h>
#include <qtcore-config.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtJambi/RegistryAPI>


class QKeyEvent_shell : public QKeyEvent, public QtJambiShellInterface
{
public:
    QKeyEvent_shell(QEvent::Type type0, int key1, Qt::KeyboardModifiers modifiers2, const QString& text3 = QString(), bool autorep4 = false, quint16 count5 = 1);
    QKeyEvent_shell(QEvent::Type type0, int key1, Qt::KeyboardModifiers modifiers2, quint32 nativeScanCode3, quint32 nativeVirtualKey4, quint32 nativeModifiers5, const QString& text6 = QString(), bool autorep7 = false, quint16 count8 = 1, const QInputDevice* device9 = QInputDevice::primaryKeyboard());
    QKeyEvent_shell(const QKeyEvent& arg__1);
    ~QKeyEvent_shell() override;

    QKeyEvent* clone() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QKeyEvent_access : public QKeyEvent
{
    void __qt_assign_cref_QKeyEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setAutoRepeat_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean autoRepeat0);
    void setCount_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jshort count0);
    void setScanCode_quint32(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint scanCode0);
    jint scanCode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setVirtualKey_quint32(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint virtualKey0);
    jint virtualKey(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QKEYEVENT_SHELL_H
